Example Gallery — chop documentation

# Example Gallery

## Miscellaneous examples

Miscellaneous and introductory examples for chop.

Constrained neural network training.

Stochastic constrained optimization dynamics.

Full-gradient constrained optimization dynamics.

## Adversarial Robustness

Examples on adversarial robustness.

Benchmark of attacks.

Example of robust training on CIFAR10.

Visualizing Adversarial Examples

Gallery generated by Sphinx-Gallery